@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: zlib-enum
-version: 0.2.1
-id: zlib-enum-0.2.1-728e49ac69ba82c426aa1ea2be6ffe48
+version: 0.2.2.1
+id: zlib-enum-0.2.2.1-850fd31afe82d4ad04cd29118b119441
 
 license: MIT
 copyright:
@@ -9,6 +9,7 @@ maintainer: Malte Sommerkorn <malte.sommerkorn@googlemail.com>
 stability: Experimental
 homepage: http://github.com/maltem/zlib-enum
 package-url:
+synopsis: Enumerator interface for zlib compression
 description: zlib-enum is a stop-gap package to provide enumeratees for
              zlib compression/decompression.
 category: Codec, Compression, Enumerator
@@ -17,23 +18,24 @@ pkgpath: archivers/hs-zlib-enum
 exposed: True
 exposed-modules: Codec.Zlib.Enum
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/zlib-enum-0.2.1
-library-dirs: /usr/local/lib/ghc/zlib-enum-0.2.1
-hs-libraries: HSzlib-enum-0.2.1
+trusted: False
+import-dirs: /usr/local/lib/ghc/zlib-enum-0.2.2.1
+library-dirs: /usr/local/lib/ghc/zlib-enum-0.2.2.1
+hs-libraries: HSzlib-enum-0.2.2.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
-         enumerator-0.4.14-9c33aff818231fce81258e5fdfab7c93
-         transformers-0.2.2.0-4bbbfde1fb5c4eb17cdb1963dda698f3
-         zlib-bindings-0.0.0-ee8291c1045b99a83a504dea1512ec80
+depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
+         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
+         enumerator-0.4.19-27ff248ca60645d7b3b73b44ac567b75
+         transformers-0.3.0.0-8e66ecc7d4dae2b07b2b5406908c70e4
+         zlib-bindings-0.1.0.1-6d927e0e33735f35669ffeb0fae76480
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-zlib-enum-0.2.1/html/zlib-enum.haddock
-haddock-html: /usr/local/share/doc/hs-zlib-enum-0.2.1/html
+haddock-interfaces: /usr/local/share/doc/hs-zlib-enum-0.2.2.1/html/zlib-enum.haddock
+haddock-html: /usr/local/share/doc/hs-zlib-enum-0.2.2.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
